@@ -2,8 +2,8 @@
 /* Generated data (by glib-mkenums) */
 
 #include "gdict-enum-types.h"
-/* enumerations from "/usr/src/ports/mate-utils/mate-utils-1.10.3-1.i686/src/mate-utils-1.10.3/mate-dictionary/libgdict/gdict-context.h" */
-#include "/usr/src/ports/mate-utils/mate-utils-1.10.3-1.i686/src/mate-utils-1.10.3/mate-dictionary/libgdict/gdict-context.h"
+/* enumerations from "/usr/src/ports/mate-utils/mate-utils-1.18.1-1.x86_64/src/mate-utils-1.18.1/mate-dictionary/libgdict/gdict-context.h" */
+#include "/usr/src/ports/mate-utils/mate-utils-1.18.1-1.x86_64/src/mate-utils-1.18.1/mate-dictionary/libgdict/gdict-context.h"
 GType
 gdict_context_error_get_type (void)
 {
@@ -26,8 +26,8 @@ gdict_context_error_get_type (void)
 
   return g_enum_type_id;
 }
-/* enumerations from "/usr/src/ports/mate-utils/mate-utils-1.10.3-1.i686/src/mate-utils-1.10.3/mate-dictionary/libgdict/gdict-client-context.h" */
-#include "/usr/src/ports/mate-utils/mate-utils-1.10.3-1.i686/src/mate-utils-1.10.3/mate-dictionary/libgdict/gdict-client-context.h"
+/* enumerations from "/usr/src/ports/mate-utils/mate-utils-1.18.1-1.x86_64/src/mate-utils-1.18.1/mate-dictionary/libgdict/gdict-client-context.h" */
+#include "/usr/src/ports/mate-utils/mate-utils-1.18.1-1.x86_64/src/mate-utils-1.18.1/mate-dictionary/libgdict/gdict-client-context.h"
 GType
 gdict_client_context_error_get_type (void)
 {
@@ -46,8 +46,8 @@ gdict_client_context_error_get_type (void)
 
   return g_enum_type_id;
 }
-/* enumerations from "/usr/src/ports/mate-utils/mate-utils-1.10.3-1.i686/src/mate-utils-1.10.3/mate-dictionary/libgdict/gdict-source.h" */
-#include "/usr/src/ports/mate-utils/mate-utils-1.10.3-1.i686/src/mate-utils-1.10.3/mate-dictionary/libgdict/gdict-source.h"
+/* enumerations from "/usr/src/ports/mate-utils/mate-utils-1.18.1-1.x86_64/src/mate-utils-1.18.1/mate-dictionary/libgdict/gdict-source.h" */
+#include "/usr/src/ports/mate-utils/mate-utils-1.18.1-1.x86_64/src/mate-utils-1.18.1/mate-dictionary/libgdict/gdict-source.h"
 GType
 gdict_source_transport_get_type (void)
 {
@@ -82,8 +82,8 @@ gdict_source_error_get_type (void)
 
   return g_enum_type_id;
 }
-/* enumerations from "/usr/src/ports/mate-utils/mate-utils-1.10.3-1.i686/src/mate-utils-1.10.3/mate-dictionary/libgdict/gdict-utils.h" */
-#include "/usr/src/ports/mate-utils/mate-utils-1.10.3-1.i686/src/mate-utils-1.10.3/mate-dictionary/libgdict/gdict-utils.h"
+/* enumerations from "/usr/src/ports/mate-utils/mate-utils-1.18.1-1.x86_64/src/mate-utils-1.18.1/mate-dictionary/libgdict/gdict-utils.h" */
+#include "/usr/src/ports/mate-utils/mate-utils-1.18.1-1.x86_64/src/mate-utils-1.18.1/mate-dictionary/libgdict/gdict-utils.h"
 GType
 gdict_context_prop_get_type (void)
 {
