@@ -477,7 +477,6 @@ gdict_source_dialog_response_cb (GtkDialog *dialog,
           gdict_show_gerror_dialog (GTK_WINDOW (dialog),
           			    _("There was an error while displaying help"),
           		 	    err);
-          g_error_free (err);
         }
 
       /* we don't want the dialog to close itself */
@@ -582,8 +581,6 @@ gdict_source_dialog_constructor (GType                  type,
 
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
   gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 2);
-  
-  gtk_widget_push_composite_child ();
 
   /* get the UI from the GtkBuilder file */
   dialog->builder = gtk_builder_new ();
@@ -671,9 +668,7 @@ gdict_source_dialog_constructor (GType                  type,
    * based on the action
    */
   update_dialog_ui (dialog);
-  
-  gtk_widget_pop_composite_child ();
-  
+
   return object;
 }
 
